@@ -1,6 +1,9 @@
+import pytest
 import pyte
+from pzp import pzp
 from pzp.finder import Finder
 from pzp.screen import Screen
+from pzp.exceptions import AcceptAction
 
 
 class FakeIO:
@@ -115,3 +118,19 @@ def test_term():
 
     finder.layout.screen.cleanup()
     assert terminal.cursor.y == 0
+
+
+@pytest.mark.timeout(5)
+def test_lazy():
+    assert pzp([1], lazy=True) == 1
+    assert pzp([], lazy=True) is None
+    assert pzp(["a", "b", "c"], input="a", lazy=True) == "a"
+    assert pzp(["a", "b", "c"], input="d", lazy=True) is None
+
+    with pytest.raises(AcceptAction) as ex:
+        pzp(["a", "b", "c"], input="a", lazy=True, handle_actions=None)
+    assert ex.value.selected_item == "a"
+
+    with pytest.raises(AcceptAction) as ex:
+        pzp(["a", "b", "c"], input="d", lazy=True, handle_actions=None)
+    assert ex.value.selected_item is None
